@@ -20,6 +20,7 @@ package org.apache.hugegraph.client;
 import org.apache.hugegraph.exception.ServerException;
 import org.apache.hugegraph.rest.AbstractRestClient;
 import org.apache.hugegraph.rest.ClientException;
+import org.apache.hugegraph.rest.RestClientConfig;
 import org.apache.hugegraph.rest.RestResult;
 import org.apache.hugegraph.serializer.PathDeserializer;
 import org.apache.hugegraph.structure.graph.Path;
@@ -45,6 +46,7 @@ public class RestClient extends AbstractRestClient {
         super(url, username, password, timeout * SECOND);
     }
 
+    @Deprecated
     public RestClient(String url, String username, String password, int timeout,
                       int maxConns, int maxConnsPerRoute,
                       String trustStoreFile, String trustStorePassword) {
@@ -52,6 +54,10 @@ public class RestClient extends AbstractRestClient {
               maxConnsPerRoute, trustStoreFile, trustStorePassword);
     }
 
+    public RestClient(String url, RestClientConfig config) {
+        super(url, config);
+    }
+
     public void apiVersion(Version version) {
         E.checkNotNull(version, "api version");
         this.apiVersion = version;
